# Un1qnx API

Simple Python API client for [un1qnx](https://un1qnx.com/).

## Configuration

| Name                | Type  | Description                                                       |
| ------------------- | ----- | ----------------------------------------------------------------- |
| **UN1QNX_BASE_URL** | `str` | The base URL to be used in the remote API calls.                  |
| **UN1QNX_AUTH_URL** | `str` | The authentication URL to be used in the authentication API call. |

## License

Un1qnx API is currently licensed under the [Apache License, Version 2.0](http://www.apache.org/licenses/).

## Build Automation

[![Build Status](https://app.travis-ci.com/ripe-tech/un1qnx-api.svg?branch=master)](https://travis-ci.com/github/ripe-tech/un1qnx-api)
[![Build Status GitHub](https://github.com/ripe-tech/un1qnx-api/workflows/Main%20Workflow/badge.svg)](https://github.com/ripe-tech/un1qnx-api/actions)
[![Coverage Status](https://coveralls.io/repos/ripe-tech/un1qnx-api/badge.svg?branch=master)](https://coveralls.io/r/ripe-tech/un1qnx-api?branch=master)
[![PyPi Status](https://img.shields.io/pypi/v/un1qnx-api.svg)](https://pypi.python.org/pypi/un1qnx-api)
[![License](https://img.shields.io/badge/license-Apache%202.0-blue.svg)](https://www.apache.org/licenses/)
